@@ -1,8 +1,11 @@
 package Plack::Middleware::DNSBL;
-use parent qw(Plack::Middleware);
-use strict; use warnings;
 
-our $VERSION = '0.03';
+use strict;
+use warnings;
+
+use parent qw(Plack::Middleware);
+
+our $VERSION = '0.03002';
 
 use Carp ();
 use Plack::Util::Accessor qw(cache cache_time resolver blacklists blacklisted);
@@ -180,7 +183,7 @@ port 80.
               ] ];
           }
   
-          [ 500, [ 'Content-type' => 'text/plain' ], [ "Die, spammer! ] ];
+          [ 500, [ 'Content-type' => 'text/plain' ], [ "Die, spammer!" ] ];
       };
 
 The C<blacklisted> option specifies a coderef that will be called at the first
@@ -225,7 +228,7 @@ A L<Net::DNS::Resolver> object. Defaults to C<< Net::DNS::Resolver->new >>.
 =head1 WHITELISTING
 
 There's no build-in way of whitelisting IPs or certain paths, however this can
-be quickly solved by using Plack::Builder's C<enable_if>:
+be quickly solved by using L<Plack::Builder>'s C<enable_if>:
 
   builder {
       enable_if {
